@@ -1,7 +1,6 @@
 import sys
 import signal
 import requests
-from xml.etree.ElementTree import VERSION
 from datetime import datetime
 from cachetools import TTLCache
 from functools import wraps
@@ -55,6 +54,19 @@ class Kable:
         else:
             self.debug = False
 
+        if "max_queue_size" in config:
+            self.maxQueueSize = config["max_queue_size"]
+            if self.maxQueueSize > 100:
+                self.maxQueueSize = 100
+        else:
+            self.maxQueueSize = 10  # flush after 10 requests queued
+
+        if "disable_cache" in config:
+            disableCache = config["disable_cache"]
+            if disableCache:
+                self.maxQueueSize = 1
+        print("Starting Kable with max_queue_size " + str(self.maxQueueSize))
+
         if "record_authentication" in config:
             self.recordAuthentication = config["record_authentication"]
             if self.recordAuthentication is False:
@@ -65,8 +77,7 @@ class Kable:
 
         self.queueFlushInterval = 10  # 10 seconds
         self.queueFlushTimer = None
-        self.queueFlushMaxCount = 10  # 10 requests
-        self.queueFlushMaxPoller = None
+        # self.queueFlushMaxPoller = None
         self.queue = []
 
         self.validCache = TTLCache(maxsize=1000, ttl=30)
@@ -84,9 +95,9 @@ class Kable:
         try:
             response = requests.post(url=url, headers=headers)
             status = response.status_code
-            if (status == 200):
+            if status == 200:
                 self.startFlushQueueOnTimer()
-                self.startFlushQueueIfFullTimer()
+                # self.startFlushQueueIfFullTimer()
 
                 self.kill = False
                 try:
@@ -108,7 +119,7 @@ class Kable:
             print("Failed to initialize Kable: Something went wrong")
 
     def record(self, data):
-        if (self.debug):
+        if self.debug:
             print("Received data to record")
 
         clientId = None
@@ -128,7 +139,7 @@ class Kable:
         @wraps(api)
         def decoratedApi(*args, **kwargs):
 
-            if (self.debug):
+            if self.debug:
                 print("Received request to authenticate")
 
             headers = request.headers
@@ -168,7 +179,7 @@ class Kable:
             try:
                 response = requests.post(url=url, headers=headers)
                 status = response.status_code
-                if (status == 200):
+                if status == 200:
                     self.validCache.__setitem__(secretKey, clientId)
                     if self.recordAuthentication:
                         self.enqueueMessage(clientId, None, {})
@@ -199,11 +210,13 @@ class Kable:
 
         library = {}
         library['name'] = 'kable-python-flask'
-        library['version'] = VERSION
+        library['version'] = '2.3.6'
 
         event['library'] = library
 
         self.queue.append(event)
+        if len(self.queue) >= self.maxQueueSize:
+            self.flushQueue()
 
     def flushQueue(self):
         if self.debug:
@@ -214,15 +227,15 @@ class Kable:
             self.queueFlushTimer.cancel()
             self.queueFlushTimer = None
 
-        if self.queueFlushMaxPoller is not None:
-            # print('Stopping size-based queue poller')
-            self.queueFlushMaxPoller.cancel()
-            self.queueFlushMaxPoller = None
+        # if self.queueFlushMaxPoller is not None:
+        #     # print('Stopping size-based queue poller')
+        #     self.queueFlushMaxPoller.cancel()
+        #     self.queueFlushMaxPoller = None
 
         events = self.queue
         self.queue = []
         count = len(events)
-        if (count > 0):
+        if count > 0:
             if self.debug:
                 print(f'Sending {count} batched events to server')
 
@@ -237,11 +250,13 @@ class Kable:
                 response = requests.post(
                     url=url, headers=headers, json=events)
                 status = response.status_code
-                if (status == 200):
+                if status == 200:
                     print(
                         f'Successfully sent {count} events to Kable server')
                 else:
                     print(f'Failed to send {count} events to Kable server')
+                    for event in events:
+                        print(f'Kable Event (Error): {event}')
 
             except Exception as e:
                 print(f'Failed to send {count} events to Kable server')
@@ -253,7 +268,7 @@ class Kable:
             sys.exit(0)
         else:
             self.startFlushQueueOnTimer()
-            self.startFlushQueueIfFullTimer()
+            # self.startFlushQueueIfFullTimer()
 
     def startFlushQueueOnTimer(self):
         if self.debug:
@@ -262,16 +277,16 @@ class Kable:
         self.queueFlushTimer = Timer(
             self.queueFlushInterval, self.flushQueue).start()
 
-    def startFlushQueueIfFullTimer(self):
-        if self.debug:
-            print('Starting size-based queue poller')
+    # def startFlushQueueIfFullTimer(self):
+    #     if self.debug:
+    #         print('Starting size-based queue poller')
 
-        self.queueMaxPoller = Timer(1, self.flushQueueIfFull).start()
+    #     self.queueMaxPoller = Timer(1, self.flushQueueIfFull).start()
 
-    def flushQueueIfFull(self):
-        events = self.queue
-        if len(events) >= self.queueFlushMaxCount:
-            self.flushQueue()
+    # def flushQueueIfFull(self):
+    #     events = self.queue
+    #     if len(events) >= self.maxQueueSize:
+    #         self.flushQueue()
 
     def exitGracefully(self, *args):
         print(
